@@ -109,9 +109,9 @@ int add_symbol_n(SYMBOL_SET *ss, const addr_t address,
     static regmatch_t *re_symbol_ver_pmatch;
     static const char procname[] = "add_symbol_n";
 
-    /* Strip out any trailing symbol version _R(smp_|smp2gig_|2gig_)?xxxxxxxx. */
+    /* Strip out any trailing symbol version _R.*xxxxxxxx. */
     RE_COMPILE(&re_symbol_ver,
-	"^(.*)_R(smp_|smp2gig_|2gig_)?[0-9a-fA-F]{8,}$",
+	"^(.*)_R.*[0-9a-fA-F]{8,}$",
 	REG_NEWLINE|REG_EXTENDED,
 	&re_symbol_ver_pmatch);
 
